==> quasar-1.2.3.tgz: package/icon-set/themify.js <==
export default {
  name: 'themify',
  type: {
    positive: 'ti-check',
    negative: 'ti-alert',
    info: 'ti-info-alt',
    warning: 'ti-alert'
  },
  arrow: {
    up: 'ti-arrow-up',
    right: 'ti-arrow-right',
    down: 'ti-arrow-down',
    left: 'ti-arrow-left',
    dropdown: 'ti-arrow-circle-down'
  },
  chevron: {
    left: 'ti-angle-left',
    right: 'ti-angle-right'
  },
  colorPicker: {
    spectrum: 'ti-brush-alt',
    tune: 'ti-panel',
    palette: 'ti-palette'
  },
  pullToRefresh: {
    icon: 'ti-reload'
  },
  carousel: {
    left: 'ti-angle-left',
    right: 'ti-angle-right',
    navigationIcon: 'ti-control-record',
    thumbnails: 'ti-layout-slider-alt'
  },
  chip: {
    remove: 'ti-close',
    selected: 'ti-check'
  },
  datetime: {
    arrowLeft: 'ti-angle-left',
    arrowRight: 'ti-angle-right',
    now: 'ti-time',
    today: 'ti-calendar'
  },
  editor: {
    bold: 'format_bold',
    italic: 'ti-Italic',
    strikethrough: 'strikethrough_s',
    underline: 'ti-underline',
    unorderedList: 'ti-list',
    orderedList: 'ti-list-ol',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'ti-link',
    toggleFullscreen: 'ti-fullscreen',
    quote: 'ti-quote-right',
    left: 'ti-align-left',
    center: 'ti-align-center',
    right: 'ti-align-right',
    justify: 'ti-align-justify',
    print: 'ti-printer',
    outdent: 'ti-angle-double-left',
    indent: 'ti-angle-double-right',
    removeFormat: 'format_clear',
    formatting: 'ti-text',
    fontSize: 'ti-smallcap',
    align: 'ti-align-left',
    hr: 'ti-minus',
    undo: 'ti-share-alt',
    redo: 'ti-share',
    header: 'ti-paragraph',
    code: 'code',
    size: 'ti-smallcap',
    font: 'font_download',
    viewSource: 'ti-shortcode'
  },
  expansionItem: {
    icon: 'ti-angle-down',
    denseIcon: 'ti-arrow-circle-down'
  },
  fab: {
    icon: 'ti-plus',
    activeIcon: 'ti-close'
  },
  field: {
    clear: 'ti-close',
    error: 'ti-alert'
  },
  pagination: {
    first: 'ti-angle-double-left',
    prev: 'ti-angle-left',
    next: 'ti-angle-right',
    last: 'ti-angle-double-right'
  },
  rating: {
    icon: 'ti-star'
  },
  stepper: {
    done: 'ti-check',
    active: 'ti-pencil',
    error: 'ti-alert'
  },
  tabs: {
    left: 'ti-angle-left',
    right: 'ti-angle-right',
    up: 'ti-angle-up',
    down: 'ti-angle-down'
  },
  table: {
    arrowUp: 'ti-arrow-up',
    warning: 'ti-alert',
    prevPage: 'ti-angle-left',
    nextPage: 'ti-angle-right'
  },
  tree: {
    icon: 'ti-control-play'
  },
  uploader: {
    done: 'ti-check',
    clear: 'ti-close',
    add: 'ti-support',
    upload: 'ti-cloud-up',
    removeQueue: 'ti-layout-media-right',
    removeUploaded: 'ti-layout-placeholder'
  }
}

==> quasar-1.7.3.tgz: package/icon-set/themify.js <==
export default {
  name: 'themify',
  type: {
    positive: 'ti-check',
    negative: 'ti-alert',
    info: 'ti-info-alt',
    warning: 'ti-alert'
  },
  arrow: {
    up: 'ti-arrow-up',
    right: 'ti-arrow-right',
    down: 'ti-arrow-down',
    left: 'ti-arrow-left',
    dropdown: 'ti-arrow-circle-down'
  },
  chevron: {
    left: 'ti-angle-left',
    right: 'ti-angle-right'
  },
  colorPicker: {
    spectrum: 'ti-brush-alt',
    tune: 'ti-panel',
    palette: 'ti-palette'
  },
  pullToRefresh: {
    icon: 'ti-reload'
  },
  carousel: {
    left: 'ti-angle-left',
    right: 'ti-angle-right',
    navigationIcon: 'ti-control-record',
    thumbnails: 'ti-layout-slider-alt'
  },
  chip: {
    remove: 'ti-close',
    selected: 'ti-check'
  },
  datetime: {
    arrowLeft: 'ti-angle-left',
    arrowRight: 'ti-angle-right',
    now: 'ti-time',
    today: 'ti-calendar'
  },
  editor: {
    bold: 'format_bold',
    italic: 'ti-Italic',
    strikethrough: 'strikethrough_s',
    underline: 'ti-underline',
    unorderedList: 'ti-list',
    orderedList: 'ti-list-ol',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'ti-link',
    toggleFullscreen: 'ti-fullscreen',
    quote: 'ti-quote-right',
    left: 'ti-align-left',
    center: 'ti-align-center',
    right: 'ti-align-right',
    justify: 'ti-align-justify',
    print: 'ti-printer',
    outdent: 'ti-angle-double-left',
    indent: 'ti-angle-double-right',
    removeFormat: 'format_clear',
    formatting: 'ti-text',
    fontSize: 'ti-smallcap',
    align: 'ti-align-left',
    hr: 'ti-minus',
    undo: 'ti-share-alt',
    redo: 'ti-share',
    heading: 'ti-paragraph',
    code: 'code',
    size: 'ti-smallcap',
    font: 'font_download',
    viewSource: 'ti-shortcode'
  },
  expansionItem: {
    icon: 'ti-angle-down',
    denseIcon: 'ti-arrow-circle-down'
  },
  fab: {
    icon: 'ti-plus',
    activeIcon: 'ti-close'
  },
  field: {
    clear: 'ti-close',
    error: 'ti-alert'
  },
  pagination: {
    first: 'ti-angle-double-left',
    prev: 'ti-angle-left',
    next: 'ti-angle-right',
    last: 'ti-angle-double-right'
  },
  rating: {
    icon: 'ti-star'
  },
  stepper: {
    done: 'ti-check',
    active: 'ti-pencil',
    error: 'ti-alert'
  },
  tabs: {
    left: 'ti-angle-left',
    right: 'ti-angle-right',
    up: 'ti-angle-up',
    down: 'ti-angle-down'
  },
  table: {
    arrowUp: 'ti-arrow-up',
    warning: 'ti-alert',
    prevPage: 'ti-angle-left',
    nextPage: 'ti-angle-right'
  },
  tree: {
    icon: 'ti-control-play'
  },
  uploader: {
    done: 'ti-check',
    clear: 'ti-close',
    add: 'ti-support',
    upload: 'ti-cloud-up',
    removeQueue: 'ti-layout-media-right',
    removeUploaded: 'ti-layout-placeholder'
  }
}
